@@ -1,9 +1,9 @@
 package Tapper::TAP::Harness;
-# git description: v5.0.8-1-gcd69c25
+# git description: v5.0.9-4-gf4866cc
 
 our $AUTHORITY = 'cpan:TAPPER';
 # ABSTRACT: Tapper - Tapper specific TAP handling
-$Tapper::TAP::Harness::VERSION = '5.0.9';
+$Tapper::TAP::Harness::VERSION = '5.0.10';
 use 5.010;
 use strict;
 use warnings;
@@ -327,6 +327,10 @@ sub _collect_meta_from_sections {
                 my $tap       = $tap_file->{tap};
                 my $filename  = $tap_file->{filename};
 
+                # no empty tap
+                $tap = join "\n", TAP::DOM->new(tap=>"", version=>13, noempty_tap=>1)->to_tap
+                  if !$tap;
+
                 my $parser = TAP::Parser->new ({ tap => $tap, version => 13 });
 
                 # ----- store previous section, start new section -----
